AnalyticsEventItemJson class

Annotations
  • @JsonSerializable.new()

Constructors

AnalyticsEventItemJson(Map<String, Object?> json)

Properties

affiliation → String?
A product affiliation to designate a supplying company or brick and mortar store location. e.g. Google Store
finalinherited
coupon → String?
The coupon name/code associated with the item. e.g. SUMMER_FUN
finalinherited
creativeName → String?
The name of the promotional creative.
finalinherited
creativeSlot → String?
The name of the promotional creative slot associated with the item.
finalinherited
currency → String?
The currency, in 3-letter ISO 4217 format. If set, event-level currency is ignored. Multiple currencies per event is not supported. Each item should set the same currency. e.g. USD
finalinherited
discount → num?
The monetary discount value associated with the item. e.g. 2.22
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
index → int?
The index/position of the item in a list. e.g. 5
finalinherited
itemBrand → String?
The brand of the item. e.g. Google
finalinherited
itemCategory → String?
The category of the item. If used as part of a category hierarchy or taxonomy then this will be the first category. e.g. Apparel
finalinherited
itemCategory2 → String?
The second category hierarchy or additional taxonomy for the item. e.g. Adult
finalinherited
itemCategory3 → String?
The third category hierarchy or additional taxonomy for the item. e.g. Shirts
finalinherited
itemCategory4 → String?
The fourth category hierarchy or additional taxonomy for the item. e.g. Crew
finalinherited
itemCategory5 → String?
The fifth category hierarchy or additional taxonomy for the item. e.g. Short sleeve
finalinherited
itemId → String?
The ID of the item. One of itemId or itemName is required. e.g. SKU_12345
finalinherited
itemListId → String?
The ID of the list in which the item was presented to the user. e.g. related_products
finalinherited
itemListName → String?
The name of the list in which the item was presented to the user. e.g. Related products
finalinherited
itemName → String?
The name of the item. One of itemId or itemName is required. e.g. Stan and Friends Tee
finalinherited
itemVariant → String?
The item variant or unique code or description for additional item details/options. e.g. green
finalinherited
locationId → String?
The location associated with the item. It's recommended to use the Google Place ID that corresponds to the associated item. A custom location ID can also be used. e.g. L_12345
finalinherited
parameters → Map<String, Object>?
Extra parameters to pass along default ones
finalinherited
price → num?
The monetary price of the item, in units of the specified currency parameter. e.g. 9.99
finalinherited
promotionId → String?
The ID of the promotion associated with the item. e.g. P_12345
finalinherited
promotionName → String?
The name of the promotion associated with the item. e.g. Summer Sale
finalinherited
quantity → int?
Item quantity. e.g. 1
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMap() → Map<String, dynamic>
Returns the current instance as a Map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited